***
* Replication Archive for
* Gerber, Alan S., Eric M. Patashnik, David Doherty, and Conor M. Dowling. 2014. Doctor Knows Best: 
* Physician Endorsements, Public Opinion, and the Politics of Comparative Effectiveness Research. 
* Journal of Health Politics, Policy and Law 39: 171-208.
***
clear 
cd "SET WORKING DIRECTORY"
use "yale020_output_final.dta" 
keep yal130 pid3 ideo5 yal001 yal006* birthyr educ race gender income yal002-yal006b  yal030-yal038 yal041a-yal041h yal038a yal038b yal042-yal049 yal010 yal011 yal012 yal013 yal014 yal020-yal025 yal039a yal039b yal040a-yal040f yal090* yal039c  yal080 yal081 yal082 yal091 treat_yal010 yal010 yal011 yal012 yal013 yal014 yal020-yal025 treat_yal020 weight 
save "replication.dta", replace

use "replication.dta", clear

set more 1
cd tables

**********************************
****** CODE DEMOGRAPHICS *********
**********************************
*Turnout
recode yal130 (1 2 3=1) (4=0) (*=.),gen(voted08)
label var voted08 "Turned out in 2008 (1=yes)"

*PID
recode pid3 (1=-1) (2=1) (3 4 5=0) (*=.), gen(party3)
label var party3 "Party ID: -1=Democrat; 0=Ind/Other; 1=Republican"
tab party3, gen(pid_)
rename pid_1 pid_democrat
rename pid_3 pid_republican
rename pid_2 pid_independent
label var pid_democrat "Democrat"
label var pid_republican "Republican"
label var pid_independent "Independent"

* turnout x pid
gen turnoutXpid=party3*voted08
label var turnoutXpid "2008 Turnout x Party ID"

*Ideology
recode ideo5 (1=1) (2=2) (3=3) (4=4) (5=5) (*=.), gen(ideology)
label var ideology "Ideology (1=v. liberal; 5=v. conservative)"

*trust Gov
recode yal001 (1=4) (2=3) (3=2) (4=1) (*=.), gen(trustgov)
label var trustgov "Government can be trusted (1=never; 4=almost always)"

*Age
gen age=2010-birthyr
label var age "Age (in years)"
recode age (18/37=1) (38/51=2) (52/64=3) (65/98=4), gen(age4)
label var age4 "Age (4-categories)"
tab age4, gen(ageD)
drop ageD1
label var ageD2 "Age: 38-51"
label var ageD3 "Age: 52-64"
label var ageD4 "Age: 65+"

*Education
label var educ "Education (1 no HS; 6 postgrad)"
recode educ (1 2=1) (3 4=2) (5 6=3) (*=.), gen(educ3)
label var educ3 "Education (3-categories)"
tab educ3, gen (educD)
drop educD1
label var educD2 "Education: Some College (Medium)"
label var educD3 "Education: 4-year College + (High)"

*Race
tab race, gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7+r_8
label var r_white "White"
label var r_black "Black"
label var r_hispanic "Hispanic"
label var r_other "Other Race"

*Gender
recode gender (1=0) (2=1), gen(female)
label var female "Female=1"

*Income
recode income (1/5=1) (6/8=2) (9/14=3) (15 98=4), gen(income3)
tab income3, gen(incomeD)
drop incomeD1
gen incomemis=incomeD4 
label var incomeD2 "Income: $30-60k (Medium)"
label var incomeD3 "Income: >$60k (High)"
label var incomeD4 "Income Missing"
label var incomemis "Income Missing"
label var income "Family Income (1=<$10k; 14=>$150k)"

** Health status/experiences
recode yal002 (1=4) (2=3) (3=2) (4=1) (*=.), gen(insurance)
label var insurance "Insurance Status (1=don't have; 4=have/it's good)"

recode yal003 (1=1) (2=2) (3=3) (4=4) (5=5) (*=.), gen(health_status)
label var health_status "Health Status (1=poor; 5=excellent)"

recode yal004 yal005 (1=1) (2=0) (*=.), gen(ser_ill_fam ser_ill_oth)
label var ser_ill_fam "Serious Illness - Family (1=yes)"
label var ser_ill_oth "Serious Illness - Other (1=yes)"


*** RECODES ***
* NOTE - IGNORE VALUE LABELS ON RECODED VARIABLES! * 
recode yal006a yal006d yal006e (1=1) (2=2) (3=3) (*=.)
recode yal006b (1=3) (2=2) (3=1) (*=.)
recode yal030-yal038 yal041a-yal041h (1=4) (2=3) (3=2) (4=1) (*=.)
recode yal038a yal038b (98/.=.)
recode yal042-yal049 (1=1) (2=2) (3=3) (4=4) (5=5) (*=.)
recode yal010 yal011 yal012 yal013 yal014 yal020-yal025 yal039a yal039b yal040a-yal040f yal090 (1=5) (2=4) (3=3) (4=2) (5=1) (*=.)
recode yal039c (8=.) 
recode yal080 yal081 yal082 yal091 (101/.=.)

*SET SAMPLE
reg yal020-yal025 yal010 yal011 yal012 yal013 yal090 party3 
keep if e(sample)

************************************************
**** MOTIVATIONS **** 
*GROUPS (Figure 3.2 in Unhealthy Politics) 
tab treat_yal010, gen(t_groups_)
foreach i of varlist yal010 yal011 yal012 yal013 yal014{
tab `i', gen(D_`i'_)
}
* Open CSV file to write to
file open myfile using "F1_F2_groups.csv", write replace 
file write myfile ",Doctor's Groups, Unions, Business Orgs., Health Insurance" _n

local labels="Maintaining high incomes for their members; Preserving the influence their group has over policy makers; Ensuring that new laws and regulations help their industry; Promoting health; Protecting doctors from malpractice suits"

foreach i of varlist yal010 yal011 yal012 yal013 yal014{
 gettoken name labels: labels, parse(";") 

forvalues x=1/4{
sum `i' [aw=weight] if t_groups_`x'==1
local val_mean_`x'=r(mean)
}

file write myfile "`name',`val_mean_1',`val_mean_2',`val_mean_3',`val_mean_4'" _n
 gettoken name labels: labels, parse(";") 
}
file write myfile "Outcomes range from 1 (Not at all important) to 5 (Extremely important)" _n
file write myfile "," _n

tab treat_yal020, gen(t_motives_)
foreach i of varlist yal020-yal025{
tab `i', gen(D_`i'_)
}

*INDIVIDUALS IN PROFESSIONS (Figure 3.1 in Unhealthy Politics)
file write myfile ",Doctors, Lawyers, Grade School Teachers, Members of Congress" _n

local labels="[Blank] work harder and longer hours than do people in most other jobs; [Blank] are interested in helping people; Becoming wealthier is important for [Blank]; [Blank] are mainly interested in gaining greater prestige"
local labels2="[Blank] care about people like me; [Blank] can be trusted"

foreach i of varlist yal020-yal025{
if "`i'"!="yal024" & "`i'"!="yal025"{
 gettoken name labels: labels, parse(";") 
}
else{
 gettoken name labels2: labels2, parse(";") 
}

forvalues x=1/4{
sum `i' [aw=weight] if t_motives_`x'==1
local val_mean_`x'=r(mean)
}

file write myfile "`name',`val_mean_1',`val_mean_2',`val_mean_3',`val_mean_4'" _n
if "`i'"!="yal024" & "`i'"!="yal025"{
 gettoken name labels: labels, parse(";") 
}
else{
 gettoken name labels2: labels2, parse(";") 
}
}
file write myfile "Outcomes range from 1 (Strongly Disagree) to 5 (Strongly Agree)" _n

file close myfile
drop D_*

* GROUP MOTIVES REGRESSIONS
foreach i of varlist yal010 yal011 yal012 yal013 yal014{
reg `i' t_groups_2 t_groups_3 t_groups_4 [aw=weight], r
}

* MOTIVES REGRESSIONS
foreach i of varlist yal020-yal025{
reg `i' t_motives_2 t_motives_3 t_motives_4 [aw=weight], r
}


******************************
*** ELITE CUES EXPERIMENT ***
******************************
tab party3, gen(pid_D)
label var pid_D1 "Democrats=1"
label var pid_D2 "Independents=1"
label var pid_D3 "Republicans=1"

gen elitecue = yal090-3
label var elitecue "Supp. for proposal (-2=much less likely to supp.; 2=much more likely to supp.)"

label var yal090_treat "AMA treatment"
label var yal090_treat2 "Party treatment"

tab yal090_treat, gen(t_ama_)
*drop t_ama_1
rename t_ama_1 t_ama_none
rename t_ama_2 t_ama_support
rename t_ama_3 t_ama_oppose

tab yal090_treat2, gen(t_party_)
*drop t_party_1
rename t_party_1 t_party_none
rename t_party_2 t_party_dem
rename t_party_3 t_party_rep
rename t_party_4 t_party_both
rename t_party_5 t_party_panel

label var t_ama_none "No AMA Cue"
label var t_ama_support "AMA Support Cue"
label var t_ama_oppose "AMA Oppose Cue"
label var t_party_none "No Party Cue"
label var t_party_dem "Democrats Support Cue"
label var t_party_rep "Republicans Support Cue"
label var t_party_both "Both Parties Support Cue"
label var t_party_panel "Bipartisan Panel Support Cue"
//gen t_party_bipartisan=t_party_both+t_party_panel
//drop t_party_panel t_party_both

foreach i in party_dem party_rep {
//foreach i in ama_support ama_oppose party_dem party_rep party_both t_party_panel t_party_both{
gen `i'Xpty3=t_`i'*party3
local tlabel : variable label t_`i'
label var `i'Xpty3 "Party ID x `tlabel'"
}

*Interactions (14 conditions)
foreach i in none dem rep both panel {
gen i_ama_none_X_party_`i' = t_ama_none*t_party_`i'
gen i_ama_support_X_party_`i' = t_ama_support*t_party_`i'
gen i_ama_oppose_X_party_`i' = t_ama_oppose*t_party_`i'
}
drop i_ama_none_X_party_none
label var i_ama_support_X_party_none "AMA Supports / No Party Cue"
label var i_ama_oppose_X_party_none "AMA Opposes / No Party Cue"
label var i_ama_none_X_party_dem "No AMA Cue / Dems Support"
label var i_ama_support_X_party_dem "AMA Supports / Dems Support"
label var i_ama_oppose_X_party_dem "AMA Opposes / Dems Support"
label var i_ama_none_X_party_rep "No AMA Cue / Reps Support"
label var i_ama_support_X_party_rep "AMA Supports / Reps Support"
label var i_ama_oppose_X_party_rep "AMA Opposes / Reps Support"
label var i_ama_none_X_party_both "No AMA Cue / Both Parties Support"
label var i_ama_support_X_party_both "AMA Supports / Both Parties Support"
label var i_ama_oppose_X_party_both "AMA Opposes / Both Parties Support"
label var i_ama_none_X_party_panel "No AMA Cue / Bipartisan Panel Supports"
label var i_ama_support_X_party_panel "AMA Supports / Bipartisan Panel Supports"
label var i_ama_oppose_X_party_panel "AMA Opposes / Bipartisan Panel Supports"

*keep weight elitecue yal090_treat yal090_treat2 t_ama_* t_party_* *Xpty3 i_ama_* party3 pid_D* voted08 age educ r_white r_black r_hispanic r_other female income incomemis
*save "C:\Documents and Settings\cmd67\My Documents\RWJF\Public Opinion Surveys\DoctorKnowsBest\Data\elite_cues_experiment.dta", replace

***************
*** BALANCE ***
***************
set seed 19654

gen chi2_treat=.
gen chi2_treat2=.

forvalues i=1/1000 {

shufflevar yal090_treat
shufflevar yal090_treat2

qui mlogit yal090_treat_shuffled age female r_black r_hispanic r_other educ income incomemis  party3 voted08 [aw=weight], base(1)
qui replace chi2_treat=e(chi2) in `i'

qui mlogit yal090_treat2_shuffled age female r_black r_hispanic r_other educ income incomemis  party3 voted08 [aw=weight], base(1)
qui replace chi2_treat2=e(chi2) in `i'
}
centile chi2_treat chi2_treat2, centile(2.5 97.5)

mlogit yal090_treat age female r_black r_hispanic r_other educ income incomemis  party3 voted08 [aw=weight], base(1)
di e(chi2)
mlogit yal090_treat2 age female r_black r_hispanic r_other educ income incomemis  party3 voted08 [aw=weight], base(1)
di e(chi2)

***Weighted and Unweighted Summary Stats
outsum age female r_black r_hispanic r_other educ income incomemis pid_D1 pid_D2 pid_D3 voted08 using "sumstats_doctors", bracket replace ctitle(February 2011 Unweighted)
outsum age female r_black r_hispanic r_other educ income incomemis pid_D1 pid_D2 pid_D3 voted08 [aw=weight] using "sumstats_doctors", bracket append ctitle(February 2011 Weighted)


***************************************************************************
*** Elite Cues Experiment: Means and Standard Errors by (14) Conditions ***
*** Table A3.2 in Unhealthy Politics
***************************************************************************
file open myfile using "T1_T2_EliteCuesExperiment.csv", write replace
file write myfile "Means with standard deviations in brackets (Outcome ranges from -2 (much less likely to support) to 2 (much more likely to support)" _n

*Full Sample
file write myfile "Condition,No Political Cue,Dems Support/Reps Oppose,Reps Support/Dems Oppose, Both Parties Support, Bipartisan Commission Supports, With No Political Cue, Without No Political Cue" _n
file write myfile _n
file write myfile "Full Sample" _n

foreach treat in 1 2 3  {
   local rowlabel : label(yal090_treat) `treat',strict
   local row "`rowlabel'"
   local sdrow ""
   forvalues treat2 = 1/5 {
	qui count if yal090_treat == `treat' & yal090_treat2 == `treat2'
	if (`r(N)'==0) {
     local row = "`row'" + "," + ""
     local sdrow = "`sdrow'" + "," + ""
	}
	else {
	     qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & yal090_treat2 == `treat2'
	     local mn = `r(mean)'
	     local se = `r(se)'
     		local row = "`row'" + "," + "`mn'"
		local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		}
		{
	     	    qui ci mean elitecue [aw=weight]  if yal090_treat == `treat'
		    local mn = `r(mean)'
		    local se = `r(se)'
	          local row = "`row'" + "," + "`mn'"
		    local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		{
		    qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & yal090_treat2 ~= 1
		    local mn = `r(mean)'
		    local se = `r(se)'
	     	    local row = "`row'" + "," + "`mn'"
	          local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		di "`row'"
		di "`sdrow'"
		file write myfile "`row'" _n
		file write myfile "`sdrow'" _n
}


*Republicans
file write myfile "Condition,No Political Cue,Dems Support/Reps Oppose,Reps Support/Dems Oppose, Both Parties Support, Bipartisan Commission Supports, With No Political Cue, Without No Political Cue" _n
file write myfile _n
file write myfile "Republicans" _n

foreach treat in 1 2 3  {
   local rowlabel : label(yal090_treat) `treat',strict
   local row "`rowlabel'"
   local sdrow ""
   forvalues treat2 = 1/5 {
	qui count if yal090_treat == `treat' & yal090_treat2 == `treat2'
	if (`r(N)'==0) {
     local row = "`row'" + "," + ""
     local sdrow = "`sdrow'" + "," + ""
	}
	else {
	     qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & yal090_treat2 == `treat2' & party3==1
	     local mn = `r(mean)'
	     local se = `r(se)'
     		local row = "`row'" + "," + "`mn'"
		local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		}
		{
	     	    qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & party3==1
		    local mn = `r(mean)'
		    local se = `r(se)'
	          local row = "`row'" + "," + "`mn'"
		    local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		{
		    qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & yal090_treat2 ~= 1 & party3==1
		    local mn = `r(mean)'
		    local se = `r(se)'
	     	    local row = "`row'" + "," + "`mn'"
	          local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		di "`row'"
		di "`sdrow'"
		file write myfile "`row'" _n
		file write myfile "`sdrow'" _n
}



*Democrats
file write myfile "Condition,No Political Cue,Dems Support/Reps Oppose,Reps Support/Dems Oppose, Both Parties Support, Bipartisan Commission Supports, With No Political Cue, Without No Political Cue" _n
file write myfile _n
file write myfile "Democrats" _n

foreach treat in 1 2 3  {
   local rowlabel : label(yal090_treat) `treat',strict
   local row "`rowlabel'"
   local sdrow ""
   forvalues treat2 = 1/5 {
	qui count if yal090_treat == `treat' & yal090_treat2 == `treat2'
	if (`r(N)'==0) {
     local row = "`row'" + "," + ""
     local sdrow = "`sdrow'" + "," + ""
	}
	else {
	     qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & yal090_treat2 == `treat2' & party3==-1
	     local mn = `r(mean)'
	     local se = `r(se)'
     		local row = "`row'" + "," + "`mn'"
		local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		}
		{
	     	    qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & party3==-1
		    local mn = `r(mean)'
		    local se = `r(se)'
	          local row = "`row'" + "," + "`mn'"
		    local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		{
		    qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & yal090_treat2 ~= 1 & party3==-1
		    local mn = `r(mean)'
		    local se = `r(se)'
	     	    local row = "`row'" + "," + "`mn'"
	          local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		di "`row'"
		di "`sdrow'"
		file write myfile "`row'" _n
		file write myfile "`sdrow'" _n
}


*Independents
file write myfile "Condition,No Political Cue,Dems Support/Reps Oppose,Reps Support/Dems Oppose, Both Parties Support, Bipartisan Commission Supports, With No Political Cue, Without No Political Cue" _n
file write myfile _n
file write myfile "Independents" _n

foreach treat in 1 2 3  {
   local rowlabel : label(yal090_treat) `treat',strict
   local row "`rowlabel'"
   local sdrow ""
   forvalues treat2 = 1/5 {
	qui count if yal090_treat == `treat' & yal090_treat2 == `treat2'
	if (`r(N)'==0) {
     local row = "`row'" + "," + ""
     local sdrow = "`sdrow'" + "," + ""
	}
	else {
	     qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & yal090_treat2 == `treat2' & party3==0
	     local mn = `r(mean)'
	     local se = `r(se)'
     		local row = "`row'" + "," + "`mn'"
		local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		}
		{
	     	    qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & party3==0
		    local mn = `r(mean)'
		    local se = `r(se)'
	          local row = "`row'" + "," + "`mn'"
		    local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		{
		    qui ci mean elitecue [aw=weight]  if yal090_treat == `treat' & yal090_treat2 ~= 1 & party3==0
		    local mn = `r(mean)'
		    local se = `r(se)'
	     	    local row = "`row'" + "," + "`mn'"
	          local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		di "`row'"
		di "`sdrow'"
		file write myfile "`row'" _n
		file write myfile "`sdrow'" _n
}



file close myfile

*******************
*** REGRESSIONS ***
*******************
***
*FOOTNOTE 18
***Without party controls
reg elitecue t_ama_support t_ama_oppose t_party_dem t_party_rep t_party_both t_party_panel [aw=weight], r
outreg2 using "elitecues_regressions.out", label se bracket replace 
reg elitecue t_ama_support t_ama_oppose t_party_dem t_party_rep t_party_both t_party_panel age female r_black r_hispanic r_other educ income incomemis party3 voted08 [aw=weight], r
outreg2 using "elitecues_regressions.out", label se bracket append

***With party controls and interactions between party and party cues
reg elitecue t_ama_support t_ama_oppose t_party_dem t_party_rep t_party_both t_party_panel *Xpty3 party3 [aw=weight], r
outreg2 using "elitecues_regressions.out", label se bracket append 

reg elitecue t_ama_support t_ama_oppose t_party_dem t_party_rep t_party_both t_party_panel *Xpty3 party3 age female r_black r_hispanic r_other educ income incomemis voted08 [aw=weight], r
outreg2 using "elitecues_regressions.out", label se bracket append 

***
*SECTION 3 OF APPENDIX: TESTING FOR INTERACTIONS (RESTRICTED TO THOSE WHO RECEIVE AN AMA CUE)
***14 conditions
reg elitecue i_ama_* , r

***Interacting Experimental Conditions (Ignoring the No AMA Cue Condition)
preserve
drop if yal090_treat==1
reg elitecue t_ama_support t_party_dem t_party_rep t_party_both t_party_panel [aw=weight], r

 * Generate Interactions
 gen amaXpty_dem = t_ama_support*t_party_dem
 label var amaXpty_dem "AMA Support x Dems Support"
 gen amaXpty_rep = t_ama_support*t_party_rep
 label var amaXpty_rep "AMA Support x Reps Support"
 gen amaXpty_both = t_ama_support*t_party_both
 label var amaXpty_both "AMA Support x Both Support"
 gen amaXpty_panel = t_ama_support*t_party_panel
 label var amaXpty_panel "AMA Support x Bipartisan Panel Supports"

reg elitecue t_ama_support t_party_dem t_party_rep t_party_both t_party_panel [aw=weight], r
outreg2 using "elitecues_interactions.out", label se bracket replace 

reg elitecue t_ama_support t_party_dem t_party_rep t_party_both t_party_panel amaXpty_dem amaXpty_rep amaXpty_both amaXpty_panel [aw=weight], r
test amaXpty_dem amaXpty_rep amaXpty_both amaXpty_panel 
outreg2 using "elitecues_interactions.out", label se bracket append 

 *with covariates
reg elitecue t_ama_support t_party_dem t_party_rep t_party_both t_party_panel age female r_black r_hispanic r_other educ income incomemis party3 voted08 [aw=weight], r
outreg2 using "elitecues_interactions.out", label se bracket append
reg elitecue t_ama_support t_party_dem t_party_rep t_party_both t_party_panel amaXpty_dem amaXpty_rep amaXpty_both amaXpty_panel age female r_black r_hispanic r_other educ income incomemis party3 voted08 [aw=weight], r
test amaXpty_dem amaXpty_rep amaXpty_both amaXpty_panel 
outreg2 using "elitecues_interactions.out", label se bracket append

restore

*****************************************
*** REPORTED P-VALUES AND PERCENTAGES ***
*****************************************

*** AMA CUE (Full Sample)
* AMA Support - AMA Opposition in the "Without No Political Cue" Case
reg elitecue t_ama_support [aw=weight] if yal090_treat>1 & yal090_treat2>1, r

* AMA Support - AMA Opposition in the "With No Political Cue" Case
reg elitecue t_ama_support [aw=weight] if yal090_treat>1, r

tab elitecue [aw=weight] if t_ama_support==1 & yal090_treat>1 & yal090_treat2>1
tab elitecue [aw=weight] if t_ama_support==0 & yal090_treat>1 & yal090_treat2>1


*** POLITICAL CUE (Full Sample)
* Bipartisan Commission - No Political Cue
reg elitecue t_party_panel [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=3 & yal090_treat2~=4, r

* Bipartisan Commission - Dems Support
reg elitecue t_party_panel [aw=weight]  if yal090_treat2~=1 & yal090_treat2~=3 & yal090_treat2~=4, r

* Bipartisan Commission - Reps Support
reg elitecue t_party_panel [aw=weight]  if yal090_treat2~=1 & yal090_treat2~=2 & yal090_treat2~=4, r

* Bipartisan Commission - Both Parties Support
reg elitecue t_party_panel [aw=weight]  if yal090_treat2~=1 & yal090_treat2~=2 & yal090_treat2~=3, r

tab elitecue [aw=weight]  if t_party_panel==1 & yal090_treat2~=2 & yal090_treat2~=3 & yal090_treat2~=4
tab elitecue [aw=weight]  if t_party_panel==0 & yal090_treat2~=2 & yal090_treat2~=3 & yal090_treat2~=4


* No Political Cue - Dems Support
reg elitecue t_party_dem [aw=weight]  if yal090_treat2~=3 & yal090_treat2~=4 & yal090_treat2~=5, r

* No Political Cue - Reps Support
reg elitecue t_party_rep [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=4 & yal090_treat2~=5, r

* No Political Cue - Both Parties Support
reg elitecue t_party_both [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=3 & yal090_treat2~=5, r


* No Political Cue - Bipartisan Commission (AMA Oppose condition)
reg elitecue t_party_panel [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=3 & yal090_treat2~=4 & yal090_treat==3, r

* No Political Cue - Dems Support (AMA Oppose condition)
reg elitecue t_party_dem [aw=weight]  if yal090_treat2~=3 & yal090_treat2~=4 & yal090_treat2~=5 & yal090_treat==3, r

* No Political Cue - Reps Support (AMA Oppose condition)
reg elitecue t_party_rep [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=4 & yal090_treat2~=5 & yal090_treat==3, r

* No Political Cue - Both Parties Support (AMA Oppose condition)
reg elitecue t_party_both [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=3 & yal090_treat2~=5 & yal090_treat==3, r


* Reps Support - Both Parties Support (AMA Oppose condition)
reg elitecue t_party_both [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=1 & yal090_treat2~=5 & yal090_treat==3, r


* No Political Cue - Reps Support (AMA Support condition)
reg elitecue t_party_rep [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=4 & yal090_treat2~=5 & yal090_treat==2, r


*** AMA CUE (By Party Identification)
**Republicans
* AMA Support - AMA Opposition in the "Without No Political Cue" Case
reg elitecue t_ama_support [aw=weight]  if yal090_treat>1 & yal090_treat2>1 & party3==1, r

tab elitecue [aw=weight]  if t_ama_support==1 & yal090_treat>1 & yal090_treat2>1 & party3==1
tab elitecue [aw=weight]  if t_ama_support==0 & yal090_treat>1 & yal090_treat2>1 & party3==1

**Democrats
* AMA Support - AMA Opposition in the "Without No Political Cue" Case
reg elitecue t_ama_support [aw=weight]  if yal090_treat>1 & yal090_treat2>1 & party3==-1, r

tab elitecue [aw=weight]  if t_ama_support==1 & yal090_treat>1 & yal090_treat2>1 & party3==-1
tab elitecue [aw=weight]  if t_ama_support==0 & yal090_treat>1 & yal090_treat2>1 & party3==-1

**Independents
* AMA Support - AMA Opposition in the "Without No Political Cue" Case
reg elitecue t_ama_support [aw=weight]  if yal090_treat>1 & yal090_treat2>1 & party3==0, r

tab elitecue [aw=weight]  if t_ama_support==1 & yal090_treat>1 & yal090_treat2>1 & party3==0
tab elitecue [aw=weight]  if t_ama_support==0 & yal090_treat>1 & yal090_treat2>1 & party3==0



*** Bipartisan Commission - No Political Cue (By Party Identification)
**Republicans
reg elitecue t_party_panel [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=3 & yal090_treat2~=4 & party3==1, r

**Democrats
reg elitecue t_party_panel [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=3 & yal090_treat2~=4 & party3==-1, r

**Independents
reg elitecue t_party_panel [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=3 & yal090_treat2~=4 & party3==0, r


* No Political Cue - Dems Support (By Party Identification)
**Republicans
reg elitecue t_party_dem [aw=weight]  if yal090_treat2~=3 & yal090_treat2~=4 & yal090_treat2~=5 & party3==1, r

**Democrats
reg elitecue t_party_dem [aw=weight]  if yal090_treat2~=3 & yal090_treat2~=4 & yal090_treat2~=5 & party3==-1, r

**Independents
reg elitecue t_party_dem [aw=weight]  if yal090_treat2~=3 & yal090_treat2~=4 & yal090_treat2~=5 & party3==0, r

* No Political Cue - Reps Support (By Party Identification)
**Republicans
reg elitecue t_party_rep [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=4 & yal090_treat2~=5 & party3==1, r

**Democrats
reg elitecue t_party_rep [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=4 & yal090_treat2~=5 & party3==-1, r

**Independents
reg elitecue t_party_rep [aw=weight]  if yal090_treat2~=2 & yal090_treat2~=4 & yal090_treat2~=5 & party3==0, r


***************************************************
** Second Elite Cues Experiment
***************************************************
clear
//use "..\cces11_cer_experiment.dta" 
//keep v101 cc330 cc332 v212a v243 yal062 v278 v213 v211 v208 v246  v271 v272 yal202 yal152* yal153*  yal154 yal155 rand_ord*
//save "..\cces_experiment", replace
use "..\cces_experiment", clear
set more 1

**********************************
****** CODE DEMOGRAPHICS *********
**********************************
rename v101 weight

*Turnout
recode cc330 (1 2 3=0) (4=1) (*=.), gen(voted08)
label var voted08 "Turned out in 2008 (1=yes)"

recode cc332 (1 2 3=0) (4=1) (*=.), gen(voted10)
label var voted10 "Turned out in 2010 (1=yes)"

*PID
recode v212a (1=-1) (2=1) (3 4 5=0) (*=.), gen(party3)
label var party3 "Party ID: -1=Democrat; 0=Ind/Other; 1=Republican"
tab party3, gen(pid_D)
rename pid_D1 pid_democrat
rename pid_D3 pid_republican
rename pid_D2 pid_independent
label var pid_democrat "Democrats=1"
label var pid_republican "Republicans=1"
label var pid_independent "Independents=1"

*Turnout x PID
gen turnout08Xpid=party3*voted08
label var turnout08Xpid "2008 Turnout x Party ID"

gen turnout10Xpid=party3*voted10
label var turnout10Xpid "2010 Turnout x Party ID"

*Ideology
recode v243 (1=1) (2=2) (3=3) (4=4) (5=5) (*=.), gen(ideology)
label var ideology "Ideology (1=v. liberal; 5=v. conservative)"

*Trust Gov
recode yal062 (998=.), gen(trustgov)
label var trustgov "Government can be trusted (0=never; 100=always)"

*Age
label var v278 "Age (in years)"
recode v278 (18/37=1) (38/51=2) (52/64=3) (65/98=4), gen(age4)
label var age4 "Age (4-categories)"
tab age4, gen(ageD)
drop ageD1
label var ageD2 "Age: 38-51"
label var ageD3 "Age: 52-64"
label var ageD4 "Age: 65+"

*Education
label var v213 "Education (1 no HS; 6 postgrad)"
recode v213 (1 2=1) (3 4=2) (5 6=3) (*=.), gen(educ3)
label var educ3 "Education (3-categories)"
tab educ3, gen (educD)
drop educD1
label var educD2 "Education: Some College (Medium)"
label var educD3 "Education: 4-year College + (High)"

*Race
tab v211, gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7+r_8
label var r_white "White"
label var r_black "Black"
label var r_hispanic "Hispanic"
label var r_other "Other Race"

*Gender
recode v208 (1=0) (2=1), gen(female)
label var female "Female=1"

*Income
recode v246 (12 13 14 15 16 31=12) (97=13), gen(income)
label var income "Income (1=<10k; 12=>150k; 13=RF)"
gen incomemis = (income==13)
label var incomemis "Income Missing (1=yes)"

*Health Insurance Status
gen insurance=1
replace insurance=0 if v272==1
replace insurance=0 if v271==1 
label var insurance "Insurance Status (0=No/Not sure; 1=Yes, have health insurance)"

*********************************
*** NEW ELITE CUES EXPERIMENT ***
*********************************
*Initial (i.e., pre-treatment) Support for CER (slider)
recode yal202 (998=.), gen(cer_pre)
label var cer_pre "Initial Support for CER (0=strongly oppose; 100=strongly support)"

*Post-treatment Support for CER (slider)
recode yal152a (998 999=.), gen(cer_posta)
recode yal152b (998 999=.), gen(cer_postb)
gen cer_post=cer_posta
replace cer_post=cer_postb if cer_post==.
label var cer_post "Support for CER (0=strongly oppose; 100=strongly support)"

*Post-treatment Affect of Group Cue (slider)
recode yal153a (998 999=.), gen(group_cuea)
recode yal153c (998 999=.), gen(group_cuec)
gen group_cue=group_cuea
replace group_cue=group_cuec if group_cue==.
label var group_cue "Affect of Group Cue (0=much less likely to support; 100=much more likely to support)"

*Post-treatment Affect of Political Cue (slider)
recode yal153b (998 999=.), gen(political_cueb)
recode yal153d (998 999=.), gen(political_cued)
gen political_cue=political_cueb
replace political_cue=political_cued if political_cue==.
label var political_cue "Affect of Political Cue (0=much less likely to support; 100=much more likely to support)"

*Post-treatment Support for CER After Group Cue Switch (slider)
recode yal154 (998 999=.), gen(cer_post2)
label var cer_post2 "Support for CER 2 (0=strongly oppose; 100=strongly support)"

*Post-treatment Affect of Group Cue Switch (slider)
recode yal155 (998 999=.), gen(group_switch)
label var group_switch "Affect of Group Cue Switch (0=much less likely to support; 100=much more likely to support)"

******************************************
*** NEW ELITE CUES EXPERIMENT ANALYSIS ***
******************************************
** Variables of Interest
sum cer_pre cer_post group_cue political_cue cer_post2 group_switch

**TREATMENT CONDITIONS AND ORDER RANDOMIZATIONS**
*Group Treatment
label var yal152_treat "Group treatment"
recode yal152_treat (10=1), gen(t_group)
tab t_group, gen(t_group_)
*drop t_group_1
rename t_group_1 t_group_none
rename t_group_2 t_group_doctors_support
rename t_group_3 t_group_doctors_oppose
rename t_group_4 t_group_patadv_support
rename t_group_5 t_group_patadv_oppose
rename t_group_6 t_group_govadm_support
rename t_group_7 t_group_govadm_oppose
rename t_group_8 t_group_drugco_support
rename t_group_9 t_group_drugco_oppose

label var t_group_none "No Group Cue"
label var t_group_doctors_support "Leading Doctors Support"
label var t_group_doctors_oppose "Leading Doctors Oppose"
label var t_group_patadv_support "Leading Patient Advoacy Groups Support"
label var t_group_patadv_oppose "Leading Patient Advoacy Groups Oppose"
label var t_group_govadm_support "High-level Government Administrators Support"
label var t_group_govadm_oppose "High-level Government Administrators Oppose"
label var t_group_drugco_support "Top Drug Companies Support"
label var t_group_drugco_oppose "Top Drug Companies Oppose"

*Party Treatment
label var yal152_treat2 "Party treatment"
recode yal152_treat2 (1=0) (2=1) (5=2) (4=3) (3=4), gen(t_party)
tab t_party, gen(t_party_)
rename t_party_1 t_party_none
rename t_party_2 t_party_dem
rename t_party_3 t_party_panel
rename t_party_4 t_party_both
rename t_party_5 t_party_rep

label var t_party_none "No Political Cue"
label var t_party_dem "Democrats Support"
label var t_party_panel "Bipartisan Commission Supports"
label var t_party_both "Both Parties Support"
label var t_party_rep "Republicans Support"

*Order of Group/Party Treatments
label var rand_ord "1=Group cue first; 2=Party cue first"
tab rand_ord, gen(o_treat_)
label var o_treat_1 "0=Party cue second; 1=Group cue first"
label var o_treat_2 "0=Group cue second; 1=Party cue first"

*Order of Group/Party Questions
label var rand_ord_2 "1=Group question first; 2=Party question first"
tab rand_ord_2, gen(o_quest_)
label var o_quest_1 "0=Party question second; 1=Group question first"
label var o_quest_2 "0=Group question second; 1=Party question first"

*******************************************************************************
*** Elite Cues Experiment: Means and Standard Errors by (All) Conditions ***
*******************************************************************************
*SET SAMPLE
reg cer_post v278 female r_black r_hispanic r_other v213 income incomemis party3 voted08
keep if e(sample)

***Weighted and Unweighted Summary Stats
outsum v278 female r_black r_hispanic r_other v213 income incomemis pid_democrat pid_independent pid_republican voted08 using sumstats_doctors, bracket append ctitle(November 2011 Unweighted)
outsum v278 female r_black r_hispanic r_other v213 income incomemis pid_democrat pid_independent pid_republican voted08 [aw=weight] using sumstats_doctors, bracket append ctitle(November 2011 Weighted)

*BALANCE
 *Group Cue Treatments
set more 1
mlogit t_group v278 female r_black r_hispanic r_other v213 v246 incomemis party3 voted08 [aw=weight], base(1)
foreach i in v278 female r_black r_hispanic r_other v213 v246 incomemis party3 voted08 {
test [2]`i' [3]`i' [4]`i' [5]`i' [6]`i' [7]`i' [8]`i' [9]`i'
}

* Smallest p-value = .1171 (age)

 *Political Cue Treatments
set more 1
mlogit t_party v278 female r_black r_hispanic r_other v213 v246 incomemis party3 voted08 [aw=weight], base(0)
foreach i in v278 female r_black r_hispanic r_other v213 v246 incomemis party3 voted08 {
test [1]`i' [2]`i' [3]`i' [4]`i'
}

* Smallest p-value = .0346 (gender); chi-sq = 10.37


set seed 20654
***

gen chi2_treat_group=.
gen chi2_treat_party=.

forvalues i=1/1000 {

shufflevar t_group
shufflevar t_party

qui mlogit t_group_shuffled v278 female r_black r_hispanic r_other v213 v246 incomemis party3 voted08 [aw=weight], base(1)
qui replace chi2_treat_group=e(chi2) in `i'

qui mlogit t_party_shuffled v278 female r_black r_hispanic r_other v213 v246 incomemis party3 voted08 [aw=weight], base(0)
qui replace chi2_treat_party=e(chi2) in `i'
}
centile chi2_treat_group chi2_treat_party, centile(2.5 97.5)

mlogit t_group v278 female r_black r_hispanic r_other v213 v246 incomemis party3 voted08 [aw=weight], base(1)
di e(chi2)
mlogit t_party v278 female r_black r_hispanic r_other v213 v246 incomemis party3 voted08 [aw=weight], base(1)
di e(chi2)


*
file open myfile using "T3_EliteCuesExperiment_CCES.csv", write replace
file write myfile "Means with standard errors in brackets (Outcome ranges from 0 (strongly oppose) to 100 (strongly support)" _n

*Full Sample
file write myfile "Condition,No Political Cue,Democrats Support,Bipartisan Commission Supports,Both Parties Support,Republicans Support,With No Political Cue, Without No Political Cue" _n
file write myfile _n
file write myfile "Full Sample" _n

foreach treat in 1 2 3 4 5 6 7 8 9 {
   local rowlabel : label(t_group) `treat',strict
   local row "`rowlabel'"
   local sdrow ""
   forvalues treat2 = 0/4 {
	qui count if t_group == `treat' & t_party == `treat2'
	if (`r(N)'==0) {
     local row = "`row'" + "," + ""
     local sdrow = "`sdrow'" + "," + ""
	}
	else {
	     qui ci mean cer_post [aw=weight] if t_group == `treat' & t_party == `treat2'
	     local mn = `r(mean)'
	     local se = `r(se)'
     		local row = "`row'" + "," + "`mn'"
		local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		}
		{
	     	    qui ci mean cer_post [aw=weight] if t_group == `treat'
		    local mn = `r(mean)'
		    local se = `r(se)'
	          local row = "`row'" + "," + "`mn'"
		    local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		{
		    qui ci mean cer_post [aw=weight] if t_group == `treat' & t_party ~= 0
		    local mn = `r(mean)'
		    local se = `r(se)'
	     	    local row = "`row'" + "," + "`mn'"
	          local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		di "`row'"
		di "`sdrow'"
		file write myfile "`row'" _n
		file write myfile "`sdrow'" _n
}



*Republicans
file write myfile "Condition,No Political Cue,Democrats Support,Bipartisan Commission Supports,Both Parties Support,Republicans Support,With No Political Cue, Without No Political Cue" _n
file write myfile _n
file write myfile "Republicans" _n

foreach treat in 1 2 3 4 5 6 7 8 9 {
   local rowlabel : label(t_group) `treat',strict
   local row "`rowlabel'"
   local sdrow ""
   forvalues treat2 = 0/4 {
	qui count if t_group == `treat' & t_party == `treat2'
	if (`r(N)'==0) {
     local row = "`row'" + "," + ""
     local sdrow = "`sdrow'" + "," + ""
	}
	else {
	     qui ci mean cer_post [aw=weight] if t_group == `treat' & t_party == `treat2' & party3==1
	     local mn = `r(mean)'
	     local se = `r(se)'
     		local row = "`row'" + "," + "`mn'"
		local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		}
		{
	     	    qui ci mean cer_post [aw=weight] if t_group == `treat' & party3==1
		    local mn = `r(mean)'
		    local se = `r(se)'
	          local row = "`row'" + "," + "`mn'"
		    local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		{
		    qui ci mean cer_post [aw=weight] if t_group == `treat' & t_party ~= 0 & party3==1
		    local mn = `r(mean)'
		    local se = `r(se)'
	     	    local row = "`row'" + "," + "`mn'"
	          local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		di "`row'"
		di "`sdrow'"
		file write myfile "`row'" _n
		file write myfile "`sdrow'" _n
}



*Democrats
file write myfile "Condition,No Political Cue,Democrats Support,Bipartisan Commission Supports,Both Parties Support,Republicans Support,With No Political Cue, Without No Political Cue" _n
file write myfile _n
file write myfile "Democrats" _n

foreach treat in 1 2 3 4 5 6 7 8 9 {
   local rowlabel : label(t_group) `treat',strict
   local row "`rowlabel'"
   local sdrow ""
   forvalues treat2 = 0/4 {
	qui count if t_group == `treat' & t_party == `treat2'
	if (`r(N)'==0) {
     local row = "`row'" + "," + ""
     local sdrow = "`sdrow'" + "," + ""
	}
	else {
	     qui ci mean cer_post [aw=weight] if t_group == `treat' & t_party == `treat2' & party3==-1
	     local mn = `r(mean)'
	     local se = `r(se)'
     		local row = "`row'" + "," + "`mn'"
		local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		}
		{
	     	    qui ci mean cer_post [aw=weight] if t_group == `treat' & party3==-1
		    local mn = `r(mean)'
		    local se = `r(se)'
	          local row = "`row'" + "," + "`mn'"
		    local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		{
		    qui ci mean cer_post [aw=weight] if t_group == `treat' & t_party ~= 0 & party3==-1
		    local mn = `r(mean)'
		    local se = `r(se)'
	     	    local row = "`row'" + "," + "`mn'"
	          local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		di "`row'"
		di "`sdrow'"
		file write myfile "`row'" _n
		file write myfile "`sdrow'" _n
}




*Independents
file write myfile "Condition,No Political Cue,Democrats Support,Bipartisan Commission Supports,Both Parties Support,Republicans Support,With No Political Cue, Without No Political Cue" _n
file write myfile _n
file write myfile "Independents" _n

foreach treat in 1 2 3 4 5 6 7 8 9 {
   local rowlabel : label(t_group) `treat',strict
   local row "`rowlabel'"
   local sdrow ""
   forvalues treat2 = 0/4 {
	qui count if t_group == `treat' & t_party == `treat2'
	if (`r(N)'==0) {
     local row = "`row'" + "," + ""
     local sdrow = "`sdrow'" + "," + ""
	}
	else {
	     qui ci mean cer_post [aw=weight] if t_group == `treat' & t_party == `treat2' & party3==0
	     local mn = `r(mean)'
	     local se = `r(se)'
     		local row = "`row'" + "," + "`mn'"
		local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		}
		{
	     	    qui ci mean cer_post [aw=weight] if t_group == `treat' & party3==0
		    local mn = `r(mean)'
		    local se = `r(se)'
	          local row = "`row'" + "," + "`mn'"
		    local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		{
		    qui ci mean cer_post [aw=weight] if t_group == `treat' & t_party ~= 0 & party3==0
		    local mn = `r(mean)'
		    local se = `r(se)'
	     	    local row = "`row'" + "," + "`mn'"
	          local sdrow = "`sdrow'" + ",[" + string(`se',"%9.3f") + "]"
		}
		di "`row'"
		di "`sdrow'"
		file write myfile "`row'" _n
		file write myfile "`sdrow'" _n
}


file close myfile


*****************************************
*** REPORTED P-VALUES AND PERCENTAGES ***
*****************************************

*** DOCTORS CUE (Full Sample)
* Doctors Support - Doctors Opposition in the "Without No Political Cue" Case (column G)
reg cer_post t_group [aw=weight] if t_group==2 & t_party>0 | t_group==3 & t_party>0, r

* Doctors Support - Doctors Opposition in the "With No Political Cue" Case (column F)
reg cer_post t_group [aw=weight] if t_group==2 | t_group==3, r

* Doctors Support - No Group or Political Cue in the "With No Political Cue" Case (column A)
reg cer_post t_group [aw=weight] if t_group==2 & t_party==0 | t_group==1 & t_party==0, r

* Doctors Opposition - No Group or Political Cue in the "With No Political Cue" Case (column A)
reg cer_post t_group [aw=weight] if t_group==3 & t_party==0 | t_group==1 & t_party==0, r


*** OTHER GROUP CUES CUE (Full Sample)
* Patient Adv. Support - Patient Adv. Opposition in the "Without No Political Cue" Case (column G)
reg cer_post t_group [aw=weight] if t_group==4 & t_party>0 | t_group==5 & t_party>0, r

* Patient Adv. Support - Patient Adv. Opposition in the "With No Political Cue" Case (column F)
reg cer_post t_group [aw=weight] if t_group==4 | t_group==5, r

* Gov't Admin. Support - Gov't Admin. Opposition in the "Without No Political Cue" Case (column G)
reg cer_post t_group [aw=weight] if t_group==6 & t_party>0 | t_group==7 & t_party>0, r

* Gov't Admin. Support - Gov't Admin. Opposition in the "With No Political Cue" Case (column F)
reg cer_post t_group [aw=weight] if t_group==6 | t_group==7, r

* Drug Comp. Support - Drug Comp. Opposition in the "Without No Political Cue" Case (column G)
reg cer_post t_group [aw=weight] if t_group==8 & t_party>0 | t_group==9 & t_party>0, r

* Drug Comp. Support - Drug Comp. Opposition in the "With No Political Cue" Case (column F)
reg cer_post t_group [aw=weight] if t_group==8 | t_group==9, r


*** POLITICAL CUES (Full Sample)
reg cer_post t_party [aw=weight] if t_party==0 | t_party==1, r

reg cer_post t_party [aw=weight] if t_party==0 | t_party==2, r

reg cer_post t_party [aw=weight] if t_party==0 | t_party==3, r

reg cer_post t_party [aw=weight] if t_party==0 | t_party==4, r

reg cer_post t_party [aw=weight] if t_party==1 | t_party==2, r

reg cer_post t_party [aw=weight] if t_party==1 | t_party==3, r

reg cer_post t_party [aw=weight] if t_party==1 | t_party==4, r

reg cer_post t_party [aw=weight] if t_party==2 | t_party==3, r

reg cer_post t_party [aw=weight] if t_party==2 | t_party==4, r

reg cer_post t_party [aw=weight] if t_party==3 | t_party==4, r


*** BIPARTISAN COMMISSION (Full Sample, and then by PID)
reg cer_post t_party [aw=weight] if t_party==0 | t_party==2, r

 *** Republicans
reg cer_post t_party [aw=weight] if t_party==0 & party3==1 | t_party==2 & party3==1 , r

 *** Democrats
reg cer_post t_party [aw=weight] if t_party==0 & party3==-1 | t_party==2 & party3==-1 , r

 *** Independents
reg cer_post t_party [aw=weight] if t_party==0 & party3==0 | t_party==2 & party3==0 , r


******************
***REGRESSION
******************
preserve
drop t_group_none t_party_none

reg cer_post t_group_* t_party_* [aw=weight], r
outreg2 using "elitecues_cces.out", label se bracket replace

reg cer_post t_group_* t_party_* [aw=weight] if pid_republican==1, r
outreg2 using "elitecues_cces.out", label se bracket append

reg cer_post t_group_* t_party_* [aw=weight] if pid_democrat==1, r
outreg2 using "elitecues_cces.out", label se bracket append

reg cer_post t_group_* t_party_* [aw=weight] if pid_independent==1, r
outreg2 using "elitecues_cces.out", label se bracket append

reg cer_post t_group_* t_party_* v278 female r_black r_hispanic r_other v213 income incomemis party3 voted08 [aw=weight], r
outreg2 using "elitecues_cces.out", label se bracket append

reg cer_post t_group_* t_party_* v278 female r_black r_hispanic r_other v213 income incomemis voted08 if pid_republican==1 [aw=weight], r
outreg2 using "elitecues_cces.out", label se bracket append

reg cer_post t_group_* t_party_* v278 female r_black r_hispanic r_other v213 income incomemis voted08 if pid_democrat==1 [aw=weight], r
outreg2 using "elitecues_cces.out", label se bracket append

reg cer_post t_group_* t_party_* v278 female r_black r_hispanic r_other v213 income incomemis voted08 if pid_independent==1 [aw=weight], r
outreg2 using "elitecues_cces.out", label se bracket append

restore



